@@ -3,7 +3,7 @@
 import asyncclick as click
 import yaml
 
-from distkv.util import yprint
+from distkv.util import yprint, NotGiven, PathLongener
 
 import logging
 
@@ -34,7 +34,7 @@ async def get(obj, path, script, encode, decode):
     if not path:
         raise click.UsageError("You need a non-empty path.")
     res = await obj.client._request(
-        action="get_internal", path=("type",) + path, iter=False, nchain=obj.meta
+        action="get_internal", path=("codec",) + path, iter=False, nchain=obj.meta
     )
     if encode and res.get("encode", None) is not None:
         encode.write(res.pop("encode"))
@@ -46,10 +46,24 @@ async def get(obj, path, script, encode, decode):
     yprint(res, stream=obj.stdout)
 
 
+@cli.command()
+@click.argument("path", nargs=-1)
+@click.pass_obj
+async def list(obj, path):
+    """List type information entries"""
+    res = await obj.client._request(
+        action="get_tree_internal", path=("codec",) + path, iter=True, nchain=obj.meta
+    )
+    pl = PathLongener(())
+    async for r in res:
+        pl(r)
+        print(" ".join(str(x) for x in r.path), file=obj.stdout)
+
+
 @cli.command()
 @click.option("-e", "--encode", type=click.File(mode="r"), help="File with the encoder")
 @click.option("-d", "--decode", type=click.File(mode="r"), help="File with the decoder")
-@click.option("-d", "--data", type=click.File(mode="r"), help="File with the rest")
+@click.option("-D", "--data", type=click.File(mode="r"), help="File with the rest")
 @click.option("-i", "--in", "in_", nargs=2, multiple=True, help="Decoding sample")
 @click.option("-o", "--out", nargs=2, multiple=True, help="Encoding sample")
 @click.argument("path", nargs=-1)
@@ -63,6 +77,11 @@ async def set(obj, path, encode, decode, data, in_, out):
         msg = yaml.safe_load(data)
     else:
         msg = {}
+    chain = NotGiven
+    if "value" in msg:
+        chain = msg.get("chain", NotGiven)
+        msg = msg["value"]
+
     if "encode" in msg:
         if encode:
             raise click.UsageError("Duplicate encode script")
@@ -93,6 +112,7 @@ async def set(obj, path, encode, decode, data, in_, out):
         path=("codec",) + path,
         iter=False,
         nchain=obj.meta,
+        **({} if chain is NotGiven else {'chain':chain}),
     )
     if obj.meta:
         yprint(res, stream=obj.stdout)
@@ -102,17 +122,44 @@ async def set(obj, path, encode, decode, data, in_, out):
 @click.option(
     "-c", "--codec", multiple=True, help="Codec to link to. Multiple for hierarchical."
 )
-@click.option("-d", "--delete", help="Use to delete this converter.")
+@click.option("-d", "--delete", is_flag=True, help="Use to delete this converter.")
+@click.option("-l", "--list", is_flag=True, help="Use to list this converter; '-' to list all.")
 @click.argument("name", nargs=1)
 @click.argument("path", nargs=-1)
 @click.pass_obj
-async def convert(obj, path, codec, name, delete):
+async def convert(obj, path, codec, name, delete, list):
     """Match a codec to a path (read, if no codec given)"""
-    if not path:
+    if delete and list:
+        raise click.UsageError("You can't both list and delete a path.")
+    if not path and not list:
         raise click.UsageError("You need a non-empty path.")
     if codec and delete:
         raise click.UsageError("You can't both set and delete a path.")
 
+    if list:
+        if name == '-':
+            if path:
+                raise click.UsageError("You can't use a path here.")
+            res = await obj.client._request(
+                action="enum_internal", path=("conv",), iter=False, nchain=0, empty=True
+            )
+            for r in res.result:
+                print(r, file=obj.stdout)
+
+            
+        else:
+            res = await obj.client._request(
+                action="get_tree_internal", path=("conv",name) + path, iter=True, nchain=obj.meta
+            )
+            pl = PathLongener(())
+            async for r in res:
+                pl(r)
+                try:
+                    print(" ".join(str(x) for x in r.path), ":", " ".join(r.value['codec']), file=obj.stdout)
+                except Exception as e:
+                    print(" ".join(str(x) for x in r.path), ":", e)
+
+        return
     if delete:
         res = await obj.client._request(
             action="delete_internal", path=("conv", name) + path
@@ -132,3 +179,4 @@ async def convert(obj, path, codec, name, delete):
         print(res.tock, file=obj.stdout)
     else:
         print(" ".join(res.type), file=obj.stdout)
+
