@@ -149,9 +149,9 @@ class NodeFinder:
                 steps.append((node, True))
             # Nodes found with '#' stay on the list
             # so that they can match multiple entries.
-        if not steps:
-            raise KeyError(name)
-        if new:
+        #if not steps:
+        #    raise KeyError(name)
+        if steps and new:
             return type(self)(steps, **self.copy_args)
         else:
             self.steps = steps
@@ -352,15 +352,19 @@ class ConvEntry(MetaEntry):
     """
 
     async def set(self, value):
-        if isinstance(value.codec, str):
-            value.codec = (value.codec,)
-        elif not isinstance(value.codec, (list, tuple)):
-            raise ValueError("Codec is not a string or list")
-        try:
-            self.metaroot["codec"].follow(*value.codec, create=False)
-        except KeyError:
-            raise ClientError("This codec does not exist")
-        # crashes if nonexistent
+        if value is not NotGiven:
+            # can't run a nonexistent value through a codec
+
+            if not hasattr(value,'codec'):
+                raise ValueError("Duh? "+repr(value))
+            if isinstance(value.codec, str):
+                value.codec = (value.codec,)
+            elif not isinstance(value.codec, (list, tuple)):
+                raise ValueError("Codec is not a string or list")
+            try:
+                self.metaroot["codec"].follow(*value.codec, create=False)
+            except KeyError:
+                raise ClientError("This codec does not exist")
         await super().set(value)
 
 
